/*
	gba.h
	Use a GameBoy Advance as a GameCube Controller or print characters on screen.

 Copyright (c) 2016-2017 FIX94, Extrems, Wiimpathy(Wii library)

 Redistribution and use in source and binary forms, with or without modification,
 are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice,
     this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright notice,
     this list of conditions and the following disclaimer in the documentation and/or
     other materials provided with the distribution.
  3. The name of the author may not be used to endorse or promote products derived
     from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef _GBA_H
#define _GBA_H

#ifdef __cplusplus
extern "C" {
#endif

/* Screen On/off in controller mode */
#define LCD_OFF 0
#define LCD_ON  1

/* Initialise and send the multiboot file through the GameLink cable */
extern bool GBA_Init();

/* Enter controller mode */
extern void GBA_ScanPads(int lcdmode);

/* Print a character on GBA screen */
extern int GBA_PrintChar(char letter, int port, int milliseconds);
//extern int GBA_PrintChar(char letter, int port);

/* Print text on GBA screen */
extern int GBA_PrintText(const char* text, int port);

/* Print text on GBA screen from a file given by path */
extern bool GBA_PrintFile(const char* path, int port);

/* Reset GBA */
extern void GBA_Reset(int port);

/* Clear the GBA screen */
extern void GBA_ClearScreen(int port);

extern void GBA_TextMode(int port);

#ifdef __cplusplus
}
#endif

#endif // _LIBGBA_H
